@@ -1,4 +1,6 @@
-#include <set>
+#define R_NO_REMAP
+
+#include <iostream>
 #include <fstream>
 #include <R.h>
 #include <Rinternals.h>
@@ -6,6 +8,7 @@
 #include "PenaltyGraph.h"
 #include "MaxFlowGraph.h"
 #include "Groups.h"
+#include <set>
 #include "FLSAGeneral.h"
 #include "helperFuncsSEXP.h"
 
@@ -40,7 +43,7 @@ SEXP FLSAGeneralMain(SEXP connList, SEXP startValues, SEXP lambdas, SEXP maxSpli
     else
     {
         SEXP nodes;
-        PROTECT(nodes = allocVector(INTSXP, highNode+1));
+        PROTECT(nodes = Rf_allocVector(INTSXP, highNode+1));
         for(int i=0; i<=highNode; ++i) {
             INTEGER(nodes)[i]=i;
         }
